/*
 * ESP8266 RGBW controller
 * Copyright 2020 (c) Mark van Renswoude
 *
 * https://git.x2software.net/pub/RGBWifi
*/
#include "./system.h"
#include <ArduinoJson.h>
#include <FS.h>
#include "../debug.h"
#include "../global.h"
#include "../config.h"



void SystemSettings::toJson(Print &print)
{
  DynamicJsonDocument jsonDocument(1024);

  JsonObject pins = jsonDocument.createNestedObject("pins");
  pins["ledAP"] = pinLEDAP();
  pins["ledSTA"] = pinLEDSTA();
  pins["apButton"] = pinAPButton();

  serializeJson(jsonDocument, print);
}


bool SystemSettings::fromJson(JsonVariant &jsonDocument, bool* changed)
{
  if (changed != nullptr)
    *changed = false;

  JsonObject pins = jsonDocument["pins"];
  uint8_t jsonPinLEDAP = pins["ledAP"];
  uint8_t jsonPinLEDSTA = pins["ledSTA"];
  uint8_t jsonPinAPButton = pins["apButton"];

  if (jsonPinLEDAP == 0) jsonPinLEDAP = pinLEDAP();
  if (jsonPinLEDSTA == 0) jsonPinLEDSTA = pinLEDSTA();
  if (jsonPinAPButton == 0) jsonPinAPButton = pinAPButton();

  if ((jsonPinLEDAP != pinLEDAP()) ||
      (jsonPinLEDSTA != pinLEDSTA()) ||
      (jsonPinAPButton != pinAPButton()))
  {
    pinLEDAP(jsonPinLEDAP);
    pinLEDSTA(jsonPinLEDSTA);
    pinAPButton(jsonPinAPButton);

    if (changed != nullptr)
      *changed = true;
  }

  return true;
}